@@ -23,6 +23,7 @@
 *
 * ============================================================ */
 
+
 // Self Includes
 #include "adblockrulefallbackimpl.h"
 
@@ -35,13 +36,16 @@
 #include <QStringList>
 
 
+
 static inline bool isRegExpFilter(const QString &filter)
 {
     return filter.startsWith(QL1C('/')) && filter.endsWith(QL1C('/'));
 }
 
+
 AdBlockRuleFallbackImpl::AdBlockRuleFallbackImpl(const QString &filter)
-        : AdBlockRuleImpl(filter)
+    : AdBlockRuleImpl(filter)
+    , m_thirdPartyOption(false)
 {
     m_regExp.setCaseSensitivity(Qt::CaseInsensitive);
     m_regExp.setPatternSyntax(QRegExp::RegExp2);
@@ -57,14 +61,17 @@ AdBlockRuleFallbackImpl::AdBlockRuleFallbackImpl(const QString &filter)
         if (options.contains(QL1S("match-case")))
             m_regExp.setCaseSensitivity(Qt::CaseSensitive);
 
-        foreach(const QString &option, options)
+        if (options.contains(QL1S("third-party")))
+            m_thirdPartyOption = true;
+
+        foreach(const QString & option, options)
         {
             // Domain restricted filter
             const QString domainKeyword(QL1S("domain="));
             if (option.startsWith(domainKeyword))
             {
                 QStringList domainList = option.mid(domainKeyword.length()).split(QL1C('|'));
-                foreach(const QString &domain, domainList)
+                foreach(const QString & domain, domainList)
                 {
                     if (domain.startsWith(QL1C('~')))
                         m_whiteDomains.insert(domain.toLower());
@@ -83,8 +90,18 @@ AdBlockRuleFallbackImpl::AdBlockRuleFallbackImpl(const QString &filter)
     m_regExp.setPattern(parsedLine);
 }
 
+
 bool AdBlockRuleFallbackImpl::match(const QNetworkRequest &request, const QString &encodedUrl, const QString &) const
 {
+    if (m_thirdPartyOption)
+    {
+        const QString referer = request.rawHeader("referer");
+        const QString host = request.url().host();
+
+        if (referer.contains(host)) // is NOT third party
+            return false;
+    }
+
     const bool regexpMatch = m_regExp.indexIn(encodedUrl) != -1;
 
     if (regexpMatch && (!m_whiteDomains.isEmpty() || !m_blackDomains.isEmpty()))
@@ -110,6 +127,7 @@ bool AdBlockRuleFallbackImpl::match(const QNetworkRequest &request, const QStrin
     return regexpMatch;
 }
 
+
 QString AdBlockRuleFallbackImpl::convertPatternToRegExp(const QString &wildcardPattern)
 {
     QString pattern = wildcardPattern;
