@@ -178,7 +178,6 @@ int Application::newInstance()
     if (isRekonqCrashed && isFirstLoad)
     {
         loadUrl(KUrl("about:closedTabs"), Rekonq::NewWindow);
-        mainWindow()->currentTab()->showMessageBar();
     }
 
     if (areThereArguments)
@@ -266,8 +265,24 @@ int Application::newInstance()
 
     if (isFirstLoad)
     {
-        // give me some time to do the other things..
-        QTimer::singleShot(100, this, SLOT(postLaunch()));
+        // updating rekonq configuration
+        updateConfiguration();
+
+        setWindowIcon(KIcon("rekonq"));
+
+        historyManager();
+
+        // bookmarks loading
+        connect(bookmarkProvider(), SIGNAL(openUrl(const KUrl&, const Rekonq::OpenType&)),
+                instance(), SLOT(loadUrl(const KUrl&, const Rekonq::OpenType&)));
+
+        // crash recovering
+        if (ReKonfig::recoverOnCrash())
+        {
+            mainWindow()->currentTab()->showMessageBar();
+        }
+        ReKonfig::setRecoverOnCrash(ReKonfig::recoverOnCrash() + 1);
+        saveConfiguration();
     }
 
     return exitValue;
@@ -280,25 +295,6 @@ Application *Application::instance()
 }
 
 
-void Application::postLaunch()
-{
-    // updating rekonq configuration
-    updateConfiguration();
-
-    setWindowIcon(KIcon("rekonq"));
-
-    historyManager();
-
-    // bookmarks loading
-    connect(bookmarkProvider(), SIGNAL(openUrl(const KUrl&, const Rekonq::OpenType&)),
-            instance(), SLOT(loadUrl(const KUrl&, const Rekonq::OpenType&)));
-
-    // crash recovering
-    ReKonfig::setRecoverOnCrash(ReKonfig::recoverOnCrash() + 1);
-    saveConfiguration();
-}
-
-
 void Application::saveConfiguration() const
 {
     ReKonfig::self()->writeConfig();
@@ -435,7 +431,6 @@ void Application::loadUrl(const KUrl& url, const Rekonq::OpenType& type)
     barForTab->setQUrl(url);
 
     WebView *view = tab->view();
-
     if (view)
     {
         FilterUrlJob *job = new FilterUrlJob(view, url.pathOrUrl(), this);
@@ -463,6 +458,7 @@ MainWindow *Application::newMainWindow(bool withTab)
 void Application::removeMainWindow(MainWindow *window)
 {
     m_mainWindows.removeOne(window);
+    kDebug() << "Removing Window from app window list...";
 }
 
 
