@@ -54,31 +54,20 @@ BookmarkProvider::BookmarkProvider(QObject *parent)
     , m_owner(0)
     , m_actionCollection(new KActionCollection(this))
 {
-    // NOTE
-    // This hackish code is needed to continue sharing bookmarks with konqueror,
-    // until we can (hopefully) start using an akonadi resource.
-    //
-    // The cleanest code has a subdole bug inside does not allowing people to start
-    // using rekonq and then using konqueror. So if konqueror bk file has not just been created,
-    // bk are stored in rekonq dir and then they will be lost when you start using konqi
+    m_manager = KBookmarkManager::userBookmarksManager();
+    const QString bookmarksFile = KStandardDirs::locateLocal("data", QString::fromLatin1("konqueror/bookmarks.xml"));
 
-    KUrl bookfile = KUrl("~/.kde/share/apps/konqueror/bookmarks.xml");  // share konqueror bookmarks
-    if (!QFile::exists(bookfile.path()))
+    if (!QFile::exists(bookmarksFile))
     {
-        bookfile = KUrl("~/.kde4/share/apps/konqueror/bookmarks.xml");
-        if (!QFile::exists(bookfile.path()))
-        {
-            QString bookmarksDefaultPath = KStandardDirs::locate("appdata" , "defaultbookmarks.xbel");
-            QFile bkms(bookmarksDefaultPath);
-            QString bookmarksPath = KStandardDirs::locateLocal("appdata", "bookmarks.xml", true);
-            bookmarksPath.replace("rekonq", "konqueror");
-            bkms.copy(bookmarksPath);
-            bookfile = KUrl(bookmarksPath);
-        }
-    }
+        kDebug() << "copying of defaultbookmarks.xbel ...";
 
-    m_manager = KBookmarkManager::managerForFile(bookfile.path(), "rekonq");
-    m_manager->setEditorOptions("", true);
+        QString bookmarksDefaultPath = KStandardDirs::locate("appdata" , "defaultbookmarks.xbel");
+        KBookmarkManager *tempManager = KBookmarkManager::managerForExternalFile(bookmarksDefaultPath);
+
+        copyBookmarkGroup(tempManager->root(), rootGroup());
+        m_manager->emitChanged();
+        delete tempManager;
+    }
 
     connect(m_manager, SIGNAL(changed(const QString &, const QString &)),
             this, SLOT(slotBookmarksChanged()));
@@ -101,15 +90,13 @@ BookmarkProvider::~BookmarkProvider()
 
 KActionMenu* BookmarkProvider::bookmarkActionMenu(QWidget *parent)
 {
-    kDebug() << "creating a bookmarks action menu...";
-    
     KMenu *menu = new KMenu(parent);
     KActionMenu *bookmarkActionMenu = new KActionMenu(menu);
     bookmarkActionMenu->setMenu(menu);
     bookmarkActionMenu->setText(i18n("&Bookmarks"));
     BookmarkMenu *bMenu = new BookmarkMenu(m_manager, m_owner, menu, m_actionCollection);
     bMenu->setParent(menu);
-    
+
     return bookmarkActionMenu;
 }
 
@@ -192,7 +179,7 @@ KBookmark BookmarkProvider::bookmarkForUrl(const KUrl &url)
 
 void BookmarkProvider::slotBookmarksChanged()
 {
-    foreach(BookmarkToolBar *bookmarkToolBar, m_bookmarkToolBars)
+    foreach(BookmarkToolBar * bookmarkToolBar, m_bookmarkToolBars)
     {
         if (bookmarkToolBar)
         {
@@ -219,7 +206,7 @@ void BookmarkProvider::fillBookmarkBar(BookmarkToolBar *toolBar)
             menuAction->setDelayed(false);
             BookmarkMenu *bMenu = new BookmarkMenu(bookmarkManager(), bookmarkOwner(), menuAction->menu(), bookmark.address());
             bMenu->setParent(menuAction->menu());
-            
+
             connect(menuAction->menu(), SIGNAL(aboutToShow()), toolBar, SLOT(menuDisplayed()));
             connect(menuAction->menu(), SIGNAL(aboutToHide()), toolBar, SLOT(menuHidden()));
 
@@ -244,7 +231,7 @@ void BookmarkProvider::fillBookmarkBar(BookmarkToolBar *toolBar)
 
 void BookmarkProvider::slotPanelChanged()
 {
-    foreach(BookmarksPanel *panel, m_bookmarkPanels)
+    foreach(BookmarksPanel * panel, m_bookmarkPanels)
     {
         if (panel && panel != sender())
             panel->loadFoldedState();
@@ -266,7 +253,7 @@ void BookmarkProvider::find(QList<KBookmark> *list, const KBookmark &bookmark, c
     {
         QStringList words = text.split(' ');
         bool matches = true;
-        foreach(const QString &word, words)
+        foreach(const QString & word, words)
         {
             if (!bookmark.url().url().contains(word, Qt::CaseInsensitive)
                     && !bookmark.fullText().contains(word, Qt::CaseInsensitive))
@@ -303,3 +290,31 @@ KBookmark BookmarkProvider::bookmarkForUrl(const KBookmark &bookmark, const KUrl
 
     return found;
 }
+
+
+void BookmarkProvider::copyBookmarkGroup(const KBookmarkGroup &groupToCopy, KBookmarkGroup destGroup)
+{
+    KBookmark bookmark = groupToCopy.first();
+    while (!bookmark.isNull())
+    {
+        if (bookmark.isGroup())
+        {
+            KBookmarkGroup newDestGroup = destGroup.createNewFolder(bookmark.text());
+            if (bookmark.toGroup().isToolbarGroup())
+            {
+                newDestGroup.internalElement().setAttribute("toolbar", "yes");
+                newDestGroup.setIcon("bookmark-toolbar");
+            }
+            copyBookmarkGroup(bookmark.toGroup(), newDestGroup);
+        }
+        else if (bookmark.isSeparator())
+        {
+            destGroup.createNewSeparator();
+        }
+        else
+        {
+            destGroup.addBookmark(bookmark.text(), bookmark.url());
+        }
+        bookmark = groupToCopy.next(bookmark);
+    }
+}
