@@ -44,8 +44,8 @@
 
 
 BtmItem::BtmItem(const KBookmark &bm)
-        : m_parent(0)
-        , m_kbm(bm)
+    : m_parent(0)
+    , m_kbm(bm)
 {
 }
 
@@ -94,6 +94,13 @@ QVariant BtmItem::data(int role) const
             tooltip += url;
         }
 
+        if (!m_kbm.description().isEmpty())
+        {
+            if (!tooltip.isEmpty())
+                tooltip += '\n';
+            tooltip += m_kbm.description();
+        }
+
         return tooltip;
     }
 
@@ -156,8 +163,8 @@ KBookmark BtmItem::getBkm() const
 
 
 BookmarksTreeModel::BookmarksTreeModel(QObject *parent)
-        : QAbstractItemModel(parent)
-        , m_root(0)
+    : QAbstractItemModel(parent)
+    , m_root(0)
 {
     resetModel();
     connect(rApp->bookmarkProvider()->bookmarkManager(), SIGNAL(changed(const QString &, const QString &)), this, SLOT(bookmarksChanged(const QString &)));
@@ -337,7 +344,7 @@ void BookmarksTreeModel::bookmarksChanged(const QString &groupAddress)
         QStringList indexChain(groupAddress.split('/', QString::SkipEmptyParts));
         bool ok;
         int i;
-        foreach(const QString &sIndex, indexChain)
+        foreach(const QString & sIndex, indexChain)
         {
             i = sIndex.toInt(&ok);
             if (!ok)
