@@ -46,6 +46,7 @@
 #include <QTimer>
 #include <QSortFilterProxyModel>
 #include <QWebHistoryInterface>
+#include <QWebHistory>
 
 #include <math.h>
 
@@ -63,37 +64,75 @@ public:
                          const QDateTime &d = QDateTime(),
                          const QString &t = QString()
                         )
-            : title(t)
-            , url(u)
-            , dateTime(d)
-            , visitCount(1)
+        : title(t)
+        , url(u)
+        , firstDateTimeVisit(d)
+        , lastDateTimeVisit(d)
+        , visitCount(1)
     {}
 
     inline bool operator==(const HistoryItem &other) const
     {
         return other.title == title
                && other.url == url
-               && other.dateTime == dateTime;
+               && other.firstDateTimeVisit == firstDateTimeVisit
+               && other.lastDateTimeVisit == lastDateTimeVisit;
     }
 
     inline qreal relevance() const
     {
-        return log(visitCount) - log(dateTime.daysTo(QDateTime::currentDateTime()) + 1);
+        return log(visitCount) - log(lastDateTimeVisit.daysTo(QDateTime::currentDateTime()) + 1);
     }
 
     // history is sorted in reverse
     inline bool operator <(const HistoryItem &other) const
     {
-        return relevance() > other.relevance();
+        return lastDateTimeVisit > other.lastDateTimeVisit;
     }
 
     QString title;
     QString url;
-    QDateTime dateTime;
+    QDateTime firstDateTimeVisit;
+    QDateTime lastDateTimeVisit;
     int visitCount;
 };
 
 
+// ---------------------------------------------------------------------------------------------------------------
+
+class TabHistory
+{
+public:
+    explicit TabHistory(QWebHistory *h = 0)
+    {
+        if (h)
+        {
+            title = h->currentItem().title();
+            url = h->currentItem().url().toString();
+            QDataStream stream(&history, QIODevice::ReadWrite);
+            stream << *h;
+        }
+    }
+
+    inline bool operator ==(const TabHistory &other) const
+    {
+        return history == other.history;
+    }
+
+    void applyHistory(QWebHistory *h)
+    {
+        if (h)
+        {
+            QDataStream stream(&history, QIODevice::ReadOnly);
+            stream >> *h;
+        }
+    }
+
+    QString title;
+    QString url;
+    QByteArray history;
+};
+
 // ---------------------------------------------------------------------------------------------------------------
 
 
