@@ -42,7 +42,6 @@
 
 // Forward Declarations
 class HistoryItem;
-class MainWindow;
 class StackedUrlBar;
 class TabBar;
 class UrlBar;
@@ -65,7 +64,7 @@ class REKONQ_TESTS_EXPORT MainView : public KTabWidget
     Q_OBJECT
 
 public:
-    MainView(MainWindow *parent);
+    MainView(QWidget *parent);
 
     inline StackedUrlBar *widgetBar() const
     {
@@ -79,6 +78,8 @@ public:
 
     WebTab *webTab(int index) const;
 
+    void addNewTabButton(QAction *);
+
     /**
      * show and hide TabBar if user doesn't choose
      * "Always Show TabBar" option
@@ -113,6 +114,7 @@ Q_SIGNALS:
     void browserTabLoading(bool);
     void openPreviousInHistory();
     void openNextInHistory();
+    void closeWindow();
 
     void printRequested(QWebFrame *frame);
 
@@ -162,8 +164,6 @@ private Q_SLOTS:
 
     void windowCloseRequested();
 
-    void postLaunch();
-
 protected:
     virtual void resizeEvent(QResizeEvent *event);
 
@@ -187,14 +187,15 @@ private:
 
     QString m_loadingGitPath;
 
+    // The original width hint of the mainview for tabs width
+    int m_originalWidthHint;
+
     // the new tab button
     QToolButton *m_addTabButton;
 
     int m_currentTabIndex;
 
     QList<TabHistory> m_recentlyClosedTabs;
-
-    MainWindow *m_parentWindow;
 };
 
 #endif // MAINVIEW_H
