@@ -99,6 +99,7 @@
 #include <QtWebKit/QWebHistory>
 
 #include <QSignalMapper>
+#include <QTextDocument>
 
 
 MainWindow::MainWindow()
@@ -118,6 +119,9 @@ MainWindow::MainWindow()
     , m_hidePopupTimer(new QTimer(this))
     , m_rekonqMenu(0)
 {
+    // Setting attributes (just to be sure...)
+    setAttribute(Qt::WA_DeleteOnClose, true);
+
     // creating a centralWidget containing panel, m_view and the hidden findbar
     QWidget *centralWidget = new QWidget;
     centralWidget->setContentsMargins(0, 0, 0, 0);
@@ -139,6 +143,9 @@ MainWindow::MainWindow()
     // then, setup our actions
     setupActions();
 
+    // BEFORE setupGUI, AFTER setupActions!!
+    m_view->addNewTabButton(actionByName("new_tab"));
+
     // setting Panels
     setupPanels();
 
@@ -161,8 +168,56 @@ MainWindow::MainWindow()
     // no more status bar..
     setStatusBar(0);
 
-    // give me some time to do all the other stuffs...
-    QTimer::singleShot(100, this, SLOT(postLaunch()));
+    setupBookmarksAndToolsShortcuts();
+
+    // setting popup notification
+    connect(rApp, SIGNAL(focusChanged(QWidget*, QWidget*)), m_popup, SLOT(hide()));
+    m_popup->setAutoFillBackground(true);
+    m_popup->setMargin(4);
+    m_popup->raise();
+    m_popup->hide();
+    connect(m_hidePopupTimer, SIGNAL(timeout()), m_popup, SLOT(hide()));
+
+    // notification system
+    connect(m_view, SIGNAL(showStatusBarMessage(const QString&, Rekonq::Notify)), this, SLOT(notifyMessage(const QString&, Rekonq::Notify)));
+    connect(m_view, SIGNAL(linkHovered(const QString&)), this, SLOT(notifyMessage(const QString&)));
+
+    // connect signals and slots
+    connect(m_view, SIGNAL(currentTitle(const QString &)), this, SLOT(updateWindowTitle(const QString &)));
+    connect(m_view, SIGNAL(printRequested(QWebFrame *)), this, SLOT(printRequested(QWebFrame *)));
+    connect(m_view, SIGNAL(closeWindow()), this, SLOT(close()));
+
+    // (shift +) ctrl + tab switching
+    connect(this, SIGNAL(ctrlTabPressed()), m_view, SLOT(nextTab()));
+    connect(this, SIGNAL(shiftCtrlTabPressed()), m_view, SLOT(previousTab()));
+
+    // wheel history navigation
+    connect(m_view, SIGNAL(openPreviousInHistory()), this, SLOT(openPrevious()));
+    connect(m_view, SIGNAL(openNextInHistory()), this, SLOT(openNext()));
+
+    // update toolbar actions signals
+    connect(m_view, SIGNAL(currentChanged(int)), this, SLOT(updateActions()));
+
+    // Change window icon according to tab icon
+    connect(m_view, SIGNAL(currentChanged(int)), this, SLOT(changeWindowIcon(int)));
+
+    // Find Bar signal
+    connect(m_findBar, SIGNAL(searchString(const QString &)), this, SLOT(find(const QString &)));
+
+    // Zoom Bar signal
+    connect(m_view, SIGNAL(currentChanged(int)), m_zoomBar, SLOT(updateSlider(int)));
+
+    // Save session on window closing
+    connect(this, SIGNAL(windowClosing()), rApp->sessionManager(), SLOT(saveSession()));
+
+    // setting up toolbars to NOT have context menu enabled
+    setContextMenuPolicy(Qt::DefaultContextMenu);
+
+    // accept d'n'd
+    setAcceptDrops(true);
+
+    // Bookmark ToolBar (needs to be setup after the call to setupGUI())
+    initBookmarkBar();
 }
 
 
@@ -229,65 +284,6 @@ void MainWindow::configureToolbars()
 }
 
 
-void MainWindow::postLaunch()
-{
-    setupBookmarksAndToolsShortcuts();
-
-    // setting popup notification
-    connect(rApp, SIGNAL(focusChanged(QWidget*, QWidget*)), m_popup, SLOT(hide()));
-    m_popup->setAutoFillBackground(true);
-    m_popup->raise();
-    m_popup->hide();
-    connect(m_hidePopupTimer, SIGNAL(timeout()), m_popup, SLOT(hide()));
-
-    // notification system
-    connect(m_view, SIGNAL(showStatusBarMessage(const QString&, Rekonq::Notify)), this, SLOT(notifyMessage(const QString&, Rekonq::Notify)));
-    connect(m_view, SIGNAL(linkHovered(const QString&)), this, SLOT(notifyMessage(const QString&)));
-
-    // connect signals and slots
-    connect(m_view, SIGNAL(currentTitle(const QString &)), this, SLOT(updateWindowTitle(const QString &)));
-    connect(m_view, SIGNAL(printRequested(QWebFrame *)), this, SLOT(printRequested(QWebFrame *)));
-
-    // (shift +) ctrl + tab switching
-    connect(this, SIGNAL(ctrlTabPressed()), m_view, SLOT(nextTab()));
-    connect(this, SIGNAL(shiftCtrlTabPressed()), m_view, SLOT(previousTab()));
-
-    // wheel history navigation
-    connect(m_view, SIGNAL(openPreviousInHistory()), this, SLOT(openPrevious()));
-    connect(m_view, SIGNAL(openNextInHistory()), this, SLOT(openNext()));
-
-    // update toolbar actions signals
-    connect(m_view, SIGNAL(currentChanged(int)), this, SLOT(updateActions()));
-
-    // Change window icon according to tab icon
-    connect(m_view, SIGNAL(currentChanged(int)), this, SLOT(changeWindowIcon(int)));
-
-    // launch it manually. Just the first time...
-    updateActions();
-
-    // Find Bar signal
-    connect(m_findBar, SIGNAL(searchString(const QString &)), this, SLOT(find(const QString &)));
-
-    // Zoom Bar signal
-    connect(m_view, SIGNAL(currentChanged(int)), m_zoomBar, SLOT(updateSlider(int)));
-
-    // Ctrl + wheel handling
-    connect(this->currentTab()->view(), SIGNAL(zoomChanged(int)), m_zoomBar, SLOT(setValue(int)));
-
-    // Save session on window closing
-    connect(this, SIGNAL(windowClosing()), rApp->sessionManager(), SLOT(saveSession()));
-
-    // setting up toolbars to NOT have context menu enabled
-    setContextMenuPolicy(Qt::DefaultContextMenu);
-
-    // accept d'n'd
-    setAcceptDrops(true);
-
-    // Bookmark ToolBar (needs to be setup after the call to setupGUI())
-    initBookmarkBar();
-}
-
-
 QSize MainWindow::sizeHint() const
 {
     QRect desktopRect = QApplication::desktop()->screenGeometry();
@@ -613,7 +609,11 @@ void MainWindow::finalizeGUI(KXMLGUIClient* client)
     KXmlGuiWindow::finalizeGUI(client);
     //update rekonqMenu when GUI has changed
     KMenu *m = qobject_cast<KMenu*>(factory()->container("rekonqMenu", this));
-    m_rekonqMenu->addActions(m->actions());
+    if (m)
+        m_rekonqMenu->addActions(m->actions());
+    else
+        kDebug() << "Could not get the rekonqMenu menu. Maybe the rekonqui.rc file wasn't found. Was"
+                 << "rekonq installed correctly?";
 }
 
 
@@ -633,6 +633,17 @@ void MainWindow::fileSaveAs()
     WebTab *w = currentTab();
     KUrl srcUrl = w->url();
 
+    if (currentTab()->page()->isOnRekonqPage())
+    {
+        KParts::ReadOnlyPart *p = currentTab()->part();
+        if (p)
+        {
+            // if this is a KParts document then the w->url() will be empty and the srcUrl
+            // must be set to the document url
+            srcUrl = p->url();
+        }
+    }
+
     // First, try with suggested file name...
     QString name = w->page()->suggestedFileName();
 
@@ -648,14 +659,14 @@ void MainWindow::fileSaveAs()
         name = srcUrl.host() + QString(".html");
     }
 
-    const QString destUrl = KFileDialog::getSaveFileName(name, QString(), this);
+    const KUrl destUrl = KFileDialog::getSaveUrl(name, QString(), this);
     if (destUrl.isEmpty())
         return;
 
     if (w->page()->isContentEditable())
     {
         QString code = w->page()->mainFrame()->toHtml();
-        QFile file(destUrl);
+        QFile file(destUrl.url());
         if (!file.open(QIODevice::WriteOnly | QIODevice::Text))
             return;
 
@@ -665,7 +676,7 @@ void MainWindow::fileSaveAs()
         return;
     }
 
-    KIO::Job *job = KIO::file_copy(srcUrl, KUrl(destUrl), -1, KIO::Overwrite);
+    KIO::Job *job = KIO::file_copy(srcUrl, destUrl, -1, KIO::Overwrite);
     job->addMetaData("MaxCacheSize", "0");  // Don't store in http cache.
     job->addMetaData("cache", "cache");     // Use entry from cache if available.
     job->uiDelegate()->setAutoErrorHandlingEnabled(true);
@@ -1176,6 +1187,8 @@ void MainWindow::notifyMessage(const QString &msg, Rekonq::Notify status)
         break;
     }
 
+    QString msgToShow = Qt::escape(msg);
+
     // useful values
     WebTab *tab = m_view->currentWebTab();
 
@@ -1188,13 +1201,13 @@ void MainWindow::notifyMessage(const QString &msg, Rekonq::Notify status)
 
     // Set Popup size
     QFontMetrics fm = m_popup->fontMetrics();
-    QSize labelSize(fm.width(msg) + 2 * margin, fm.height() + 2 * margin);
+    QSize labelSize(fm.width(msgToShow) + 2 * margin, fm.height() + 2 * margin);
 
     if (labelSize.width() > halfWidth)
         labelSize.setWidth(halfWidth);
 
     m_popup->setFixedSize(labelSize);
-    m_popup->setText(fm.elidedText(msg, Qt::ElideMiddle, labelSize.width()));
+    m_popup->setText(fm.elidedText(msgToShow, Qt::ElideMiddle, labelSize.width() - 2 * margin));
 
     const bool horizontalScrollbarIsVisible = tab->page()->currentFrame()->scrollBarMaximum(Qt::Horizontal);
     const bool verticalScrollbarIsVisible = tab->page()->currentFrame()->scrollBarMaximum(Qt::Vertical);
@@ -1553,8 +1566,9 @@ void MainWindow::setEditable(bool on)
 }
 
 
-bool MainWindow::close()
+void MainWindow::closeEvent(QCloseEvent *event)
 {
     emit windowClosing();
-    return KMainWindow::close();
+    kDebug() << "CLOSING WINDOW...";
+    KXmlGuiWindow::closeEvent(event);
 }
