@@ -492,7 +492,6 @@ KAction *EngineBar::newEngineAction(KService::Ptr engine, KService::Ptr selected
     QUrl u = engine->property("Query").toUrl();
     KUrl url = KUrl(u.toString(QUrl::RemovePath | QUrl::RemoveQuery));
 
-    kDebug() << "Engine NAME: " << engine->name() << " URL: " << url;
     KAction *a = new KAction(rApp->iconManager()->iconForUrl(url), engine->name(), this);
     a->setCheckable(true);
     if (engine->desktopEntryName() == selectedEngine->desktopEntryName()) a->setChecked(true);
@@ -607,10 +606,6 @@ QString VisualSuggestionListItem::text()
 BrowseListItem::BrowseListItem(const UrlSearchItem &item, const QString &text, QWidget *parent)
     : ListItem(item, parent)
 {
-    QString url = text;
-
-    kDebug() << text;
-
     QHBoxLayout *hLayout = new QHBoxLayout;
     hLayout->setSpacing(4);
 
