@@ -1,23 +1,29 @@
-/* This file is part of the KDE project
- *
- * Copyright (C) 2009 by Fredy Yanardi <fyanardi@gmail.com>
- * Copyright (C) 2010-2011 by  Lionel Chauvin <megabigbug@yahoo.fr>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- */
+/* ============================================================
+*
+* This file is a part of the rekonq project
+*
+* Copyright (C) 2009 by Fredy Yanardi <fyanardi@gmail.com>
+* Copyright (C) 2010-2011 by  Lionel Chauvin <megabigbug@yahoo.fr>
+*
+*
+* This program is free software; you can redistribute it and/or
+* modify it under the terms of the GNU General Public License as
+* published by the Free Software Foundation; either version 2 of
+* the License or (at your option) version 3 or any later version
+* accepted by the membership of KDE e.V. (or its successor approved
+* by the membership of KDE e.V.), which shall act as a proxy
+* defined in Section 14 of version 3 of the license.
+*
+* This program is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+* GNU General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*
+* ============================================================ */
+
 
 // Self Includes
 #include "webshortcutwidget.h"
@@ -46,7 +52,7 @@ WebShortcutWidget::WebShortcutWidget(QWidget *parent)
     setFixedWidth(350);
 
     QFormLayout *layout = new QFormLayout(this);
-    QVBoxLayout *vLay = new QVBoxLayout(this);
+    QVBoxLayout *vLay = new QVBoxLayout;
 
     // Web Search Icon
     QLabel *webSearchIcon = new QLabel(this);
@@ -78,8 +84,6 @@ WebShortcutWidget::WebShortcutWidget(QWidget *parent)
     connect(buttonBox, SIGNAL(rejected()), this, SLOT(close()));
     layout->addWidget(buttonBox);
 
-    setLayout(layout);
-
     m_providers = KServiceTypeTrader::self()->query("SearchProvider");
 
     m_wsLineEdit->setFocus();
